@@ -16,7 +16,7 @@ from requests.adapters import HTTPAdapter
 
 __author__ = 'Fred Wang (taobao-pysdk@1e20.com)'
 __title__ = 'taobaopy'
-__version__ = '3.8.0'
+__version__ = '3.9.0'
 __license__ = 'BSD License'
 __copyright__ = 'Copyright 2013 Fred Wang'
 
@@ -31,12 +31,19 @@ from datetime import datetime
 api_logger = logging.getLogger('taobao_api')
 api_error_logger = logging.getLogger('taobao_api_error')
 
-RETRY_SUB_CODES = {'isp.top-remote-unknown-error', 'isp.top-remote-connection-timeout',
-                   'isp.remote-connection-error', 'mz.emptybody',
-                   'isp.top-remote-service-unavailable', 'isp.top-remote-connection-timeout-tmall',
-                   'isp.item-update-service-error:GENERIC_FAILURE',
-                   'isp.item-update-service-error:IC_SYSTEM_NOT_READY_TRY_AGAIN_LATER',
-                   'ism.json-decode-error', 'ism.demo-error'}
+RETRY_SUB_CODES = {
+    'isp.top-remote-unknown-error',
+    'isp.top-remote-connection-timeout',
+    'isp.remote-connection-error',
+    'mz.emptybody',
+    'isp.top-remote-service-unavailable',
+    'isp.top-remote-connection-timeout-tmall',
+    'isp.item-update-service-error:GENERIC_FAILURE',
+    'isp.item-update-service-error:IC_SYSTEM_NOT_READY_TRY_AGAIN_LATER',
+    'ism.json-decode-error',
+    'ism.demo-error'
+    'isp.top-remote-service-unavailable-tmall',
+}
 
 VALUE_TO_STR = {
     type(datetime.now()): lambda v: v.strftime('%Y-%m-%d %H:%M:%S'),
